@@ -8,7 +8,7 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsadmininfoslinks` (
   `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL DEFAULT '0',
   PRIMARY KEY (`id`),
   KEY `plugin_ocsinventoryng_ocsservers_id` (`plugin_ocsinventoryng_ocsservers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 
 ### Dump table glpi_plugin_ocsinventoryng_ocslinks
@@ -20,9 +20,9 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocslinks` (
   `ocsid` int(11) NOT NULL DEFAULT '0',
   `ocs_deviceid` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `use_auto_update` tinyint(1) NOT NULL DEFAULT '1',
-  `last_update` timestamp NULL DEFAULT NULL,
-  `last_ocs_update` timestamp NULL DEFAULT NULL,
-  `last_ocs_conn` timestamp NULL DEFAULT NULL,
+  `last_update` datetime DEFAULT NULL,
+  `last_ocs_update` datetime DEFAULT NULL,
+  `last_ocs_conn` datetime default NULL,
   `ip_src` varchar(255) collate utf8_unicode_ci default NULL,
   `computer_update` longtext COLLATE utf8_unicode_ci,
   `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL DEFAULT '0',
@@ -36,9 +36,8 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocslinks` (
   KEY `ocs_deviceid` (`ocs_deviceid`),
   KEY `last_ocs_update` (`plugin_ocsinventoryng_ocsservers_id`,`last_ocs_update`),
   KEY `computers_id` (`computers_id`),
-  KEY `entities_id` (`entities_id`),
   KEY `use_auto_update` (`use_auto_update`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 
 ### Dump table glpi_plugin_ocsinventoryng_ocsservers
@@ -65,9 +64,6 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `import_general_type` tinyint(1) NOT NULL DEFAULT '1',
   `import_general_domain` tinyint(1) NOT NULL DEFAULT '1',
   `import_general_contact` tinyint(1) NOT NULL DEFAULT '1',
-  `import_user_group_default` tinyint(1) NOT NULL DEFAULT '1',
-  `import_user_location` tinyint(1) NOT NULL DEFAULT '1',
-  `import_user_group` tinyint(1) NOT NULL DEFAULT '1',
   `import_general_comment` tinyint(1) NOT NULL DEFAULT '1',
   `import_device_processor` tinyint(1) NOT NULL DEFAULT '1',
   `import_device_memory` tinyint(1) NOT NULL DEFAULT '1',
@@ -84,24 +80,18 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `import_antivirus` tinyint(1) NOT NULL DEFAULT '0',
   `import_officepack` tinyint(1) NOT NULL DEFAULT '0',
   `import_winupdatestate` tinyint(1) NOT NULL DEFAULT '0',
-  `import_proxysetting` tinyint(1) NOT NULL DEFAULT '0',
-  `import_winusers` tinyint(1) NOT NULL DEFAULT '0',
-  `import_teamviewer` tinyint(1) NOT NULL DEFAULT '0',
-  `import_osinstall` TINYINT(1) NOT NULL DEFAULT '0',
-  `import_networkshare` TINYINT(1) NOT NULL DEFAULT '0',
   `import_os_serial` tinyint(1) NOT NULL DEFAULT '1',
-  `import_customapp` TINYINT(1) NOT NULL DEFAULT '0',
-  `import_bitlocker` TINYINT(1) NOT NULL DEFAULT '0',
   `import_ip` tinyint(1) NOT NULL DEFAULT '1',
   `import_disk` tinyint(1) NOT NULL DEFAULT '1',
   `import_monitor_comment` tinyint(1) NOT NULL DEFAULT '0',
+  `states_id_default` int(11) NOT NULL DEFAULT '0',
   `tag_limit` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `tag_exclude` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `use_soft_dict` tinyint(1) NOT NULL DEFAULT '0',
   `cron_sync_number` int(11) DEFAULT '1',
   `deconnection_behavior` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `ocs_url` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `date_mod` timestamp NULL DEFAULT NULL,
+  `date_mod` datetime DEFAULT NULL,
   `comment` text COLLATE utf8_unicode_ci,
   `is_active` tinyint(1) NOT NULL DEFAULT '0',
   `use_massimport` tinyint(1) NOT NULL DEFAULT '0',
@@ -114,11 +104,9 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `ocs_version` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `conn_type` tinyint(1) NOT NULL DEFAULT '0',
   `use_cleancron` tinyint(1) NOT NULL DEFAULT '0',
-  `cleancron_nb_days` int(11) NOT NULL DEFAULT '90',
   `action_cleancron` tinyint(1) NOT NULL DEFAULT '0',
   `use_restorationcron` tinyint(1) NOT NULL DEFAULT '0',
   `delay_restorationcron` int(11) NOT NULL DEFAULT '0',
-  `use_checkruleimportentity` tinyint(1) NOT NULL DEFAULT '0',
   `importsnmp_name` tinyint(1) NOT NULL DEFAULT '0',
   `importsnmp_serial` tinyint(1) NOT NULL DEFAULT '0',
   `importsnmp_comment` tinyint(1) NOT NULL DEFAULT '0',
@@ -137,9 +125,6 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `importsnmp_computerprocessors` tinyint(1) NOT NULL DEFAULT '0',
   `importsnmp_computersoftwares` tinyint(1) NOT NULL DEFAULT '0',
   `importsnmp_computervm` tinyint(1) NOT NULL DEFAULT '0',
-  `importsnmp_computerdisks` tinyint(1) NOT NULL DEFAULT '0',
-  `import_runningprocess` tinyint(1) NOT NULL DEFAULT '0',
-  `import_service` tinyint(1) NOT NULL DEFAULT '0',
   `import_uptime` tinyint(1) NOT NULL DEFAULT '0',
   `linksnmp_name` tinyint(1) NOT NULL DEFAULT '0',
   `linksnmp_serial` tinyint(1) NOT NULL DEFAULT '0',
@@ -159,7 +144,6 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `linksnmp_computerprocessors` tinyint(1) NOT NULL DEFAULT '0',
   `linksnmp_computersoftwares` tinyint(1) NOT NULL DEFAULT '0',
   `linksnmp_computervm` tinyint(1) NOT NULL DEFAULT '0',
-  `linksnmp_computerdisks` tinyint(1) NOT NULL DEFAULT '0',
   `dohistory` tinyint(1) NOT NULL DEFAULT '1',
   `history_hardware` tinyint(1) NOT NULL DEFAULT '1',
   `history_bios` tinyint(1) NOT NULL DEFAULT '1',
@@ -172,13 +156,11 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers` (
   `history_software` tinyint(1) NOT NULL DEFAULT '1',
   `history_vm` tinyint(1) NOT NULL DEFAULT '1',
   `history_admininfos` tinyint(1) NOT NULL DEFAULT '1',
-  `history_plugins` tinyint(1) NOT NULL DEFAULT '1',
-  `history_os` tinyint(1) NOT NULL DEFAULT '1',
   PRIMARY KEY (`id`),
   KEY `date_mod` (`date_mod`),
   KEY `is_active` (`is_active`),
   KEY `use_massimport` (`use_massimport`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 ### Dump table glpi_plugin_ocsinventoryng_registrykeys
 
@@ -192,7 +174,7 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_registrykeys` (
   `ocs_name` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   PRIMARY KEY (`id`),
   KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 ### Dump table glpi_plugin_ocsinventoryng_computerwinupdates
 
@@ -201,88 +183,16 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_winupdates` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   `computers_id` int(11) NOT NULL DEFAULT '0',
   `auoptions` int(11) NOT NULL DEFAULT '0',
-  `scheduleinstalldate` timestamp NULL DEFAULT NULL,
-  `lastsuccesstime` timestamp NULL DEFAULT NULL,
-  `detectsuccesstime` timestamp NULL DEFAULT NULL,
-  `downloadsuccesstime` timestamp NULL DEFAULT NULL,
+  `scheduleinstalldate` datetime DEFAULT NULL,
+  `lastsuccesstime` datetime DEFAULT NULL,
+  `detectsuccesstime` datetime DEFAULT NULL,
+  `downloadsuccesstime` datetime DEFAULT NULL,
   PRIMARY KEY (`id`),
   KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_osinstalls
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_osinstalls`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_osinstalls` (
-  `id` INT(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` INT(11) NOT NULL DEFAULT '0',
-  `build_version` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `install_date` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `codeset` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `countrycode` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `oslanguage` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `curtimezone` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `locale` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_proxysettings
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_proxysettings`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_proxysettings` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` int(11) NOT NULL DEFAULT '0',
-  `user` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `enabled` int(11) NOT NULL DEFAULT '0',
-  `autoconfigurl` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `address` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `override` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_networkshares
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_networkshares`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_networkshares` (
-  `id` INT(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` INT(11) NOT NULL DEFAULT '0',
-  `drive` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `path` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `size` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `freespace` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `quota` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_winusers
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_winusers`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_winusers` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` int(11) NOT NULL DEFAULT '0',
-  `name` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `type` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `description` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `disabled` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  `sid` VARCHAR(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_teamviewers
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_teamviewers`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_teamviewers` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` int(11) NOT NULL DEFAULT '0',
-  `twid` varchar(255) DEFAULT NULL,
-  `version` varchar(255) DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 ### Dump table glpi_plugin_ocsinventoryng_networkports
+
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_networkports`;
 CREATE TABLE `glpi_plugin_ocsinventoryng_networkports` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -296,7 +206,7 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_networkports` (
   UNIQUE KEY `networkports_id` (`networkports_id`),
   KEY `TYPE` (`TYPE`),
   KEY `TYPEMIB` (`TYPEMIB`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 
 ### Dump table glpi_plugin_ocsinventoryng_networkporttypes
@@ -315,7 +225,7 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_networkporttypes` (
   PRIMARY KEY (`id`),
   KEY `OCS_TYPE` (`OCS_TYPE`),
   KEY `OCS_TYPEMIB` (`OCS_TYPEMIB`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 ### Dump table glpi_plugin_ocsinventoryng_ocsservers_profiles
 
@@ -327,14 +237,14 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ocsservers_profiles` (
   PRIMARY KEY (`id`),
   KEY `plugin_ocsinventoryng_ocsservers_id` (`plugin_ocsinventoryng_ocsservers_id`),
   KEY `profiles_id` (`profiles_id`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_threads`;
 CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_threads` (
    `id` int(11) NOT NULL auto_increment,
    `threadid` int(11) NOT NULL default '0',
-   `start_time` timestamp NULL DEFAULT NULL,
-   `end_time` timestamp NULL DEFAULT NULL,
+   `start_time` datetime default NULL,
+   `end_time` datetime default NULL,
    `status` int(11) NOT NULL default '0',
    `error_msg` text NOT NULL,
    `imported_machines_number` int(11) NOT NULL default '0',
@@ -352,7 +262,7 @@ CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_threads` (
    PRIMARY KEY  (`id`),
    KEY `end_time` (`end_time`),
    KEY `process_thread` (`processid`,`threadid`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_configs`;
 CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_configs` (
@@ -362,12 +272,9 @@ CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_configs` (
    `import_limit` int(11) NOT NULL default '0',
    `delay_refresh` int(11) NOT NULL default '0',
    `allow_ocs_update` tinyint(1) NOT NULL default '0',
-   `log_imported_computers` tinyint(1) NOT NULL default '0',
    `comment` text,
-   `delay_ocs` int(11) NOT NULL default '-1',
-   `use_newocs_alert` int(11) NOT NULL default '-1',
    PRIMARY KEY (`id`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_details`;
 CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_details` (
@@ -379,12 +286,12 @@ CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_details` (
    `ocsid` int(11) NOT NULL default '0',
    `computers_id` int(11) NOT NULL default '0',
    `action` int(11) NOT NULL default '0',
-   `process_time` timestamp NULL DEFAULT NULL,
+   `process_time` datetime DEFAULT NULL,
    `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL default '1',
    PRIMARY KEY (`id`),
    KEY `end_time` (`process_time`),
    KEY `process_thread` (`plugin_ocsinventoryng_threads_id`,`threadid`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_notimportedcomputers`;
 CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_notimportedcomputers` (
@@ -401,21 +308,62 @@ CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_notimportedcomputers` (
    `name` VARCHAR( 255 ) NOT NULL ,
    `ipaddr` VARCHAR( 255 ) NOT NULL ,
    `domain` VARCHAR( 255 ) NOT NULL ,
-   `last_inventory` timestamp NULL DEFAULT NULL,
+   `last_inventory` DATETIME ,
    `reason` INT( 11 ) NOT NULL ,
    PRIMARY KEY ( `id` ),
    UNIQUE KEY `ocs_id` (`plugin_ocsinventoryng_ocsservers_id`,`ocsid`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_servers`;
 CREATE TABLE IF NOT EXISTS `glpi_plugin_ocsinventoryng_servers` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL DEFAULT '0',
    `max_ocsid` int(11) DEFAULT NULL,
-   `max_glpidate` timestamp NULL DEFAULT NULL,
+   `max_glpidate` datetime DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `plugin_ocsinventoryng_ocsservers_id` (`plugin_ocsinventoryng_ocsservers_id`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+
+
+### Dump table glpi_plugin_ocsinventoryng_devicebiosdatas
+
+DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_devicebiosdatas`;
+CREATE TABLE `glpi_plugin_ocsinventoryng_devicebiosdatas` (
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `designation` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
+  `comment` text COLLATE utf8_unicode_ci,
+  `date`  varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
+  `assettag` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
+  `manufacturers_id` int(11) NOT NULL DEFAULT '0',
+  `entities_id` int(11) NOT NULL DEFAULT '0',
+  `is_recursive` tinyint(1) NOT NULL DEFAULT '0',
+  PRIMARY KEY (`id`),
+  KEY `manufacturers_id` (`manufacturers_id`),
+  KEY `entities_id` (`entities_id`),
+  KEY `is_recursive` (`is_recursive`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+
+### Dump table glpi_plugin_ocsinventoryng_items_devicebios
+
+DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_items_devicebiosdatas`;
+CREATE TABLE `glpi_plugin_ocsinventoryng_items_devicebiosdatas` (
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `items_id` int(11) NOT NULL DEFAULT '0',
+  `itemtype` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
+  `plugin_ocsinventoryng_devicebiosdatas_id` int(11) NOT NULL DEFAULT '0',
+  `is_deleted` tinyint(1) NOT NULL DEFAULT '0',
+  `is_dynamic` tinyint(1) NOT NULL DEFAULT '0',
+  `entities_id` int(11) NOT NULL DEFAULT '0',
+  `is_recursive` tinyint(1) NOT NULL DEFAULT '0',
+  PRIMARY KEY (`id`),
+  KEY `computers_id` (`items_id`),
+  KEY `plugin_ocsinventoryng_devicebiosdatas_id` (`plugin_ocsinventoryng_devicebiosdatas_id`),
+  KEY `is_deleted` (`is_deleted`),
+  KEY `is_dynamic` (`is_dynamic`),
+  KEY `entities_id` (`entities_id`),
+  KEY `is_recursive` (`is_recursive`),
+  KEY `item` (`itemtype`,`items_id`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
 ### Dump table glpi_plugin_ocsinventoryng_snmpocslinks
 
@@ -425,12 +373,13 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_snmpocslinks` (
    `items_id` int(11) NOT NULL DEFAULT '0',
    `ocs_id` int(11) NOT NULL DEFAULT '0',
    `itemtype` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
-   `last_update` timestamp NULL DEFAULT NULL,
+   `last_update` DATETIME COLLATE utf8_unicode_ci DEFAULT NULL,
    `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL DEFAULT '0',
    `linked` tinyint(1) NOT NULL DEFAULT '0',
-   PRIMARY KEY (`id`),
-  KEY `plugin_ocsinventoryng_ocsservers_id` (`plugin_ocsinventoryng_ocsservers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+   PRIMARY KEY (`id`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+
+
 
 ### Dump table glpi_plugin_ocsinventoryng_ipdiscoverlinks
 
@@ -440,99 +389,13 @@ CREATE TABLE `glpi_plugin_ocsinventoryng_ipdiscoverocslinks` (
   `items_id` int(11) NOT NULL,
   `itemtype` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
   `macaddress` varchar(255) COLLATE utf8_unicode_ci NOT NULL UNIQUE,
-  `last_update` timestamp NULL DEFAULT NULL,
+  `last_update` DATETIME COLLATE utf8_unicode_ci DEFAULT NULL,
   `subnet` varchar(40) COLLATE utf8_unicode_ci DEFAULT NULL,
   `plugin_ocsinventoryng_ocsservers_id` int(11) NOT NULL DEFAULT '0',
-  PRIMARY KEY (`id`),
-  KEY `plugin_ocsinventoryng_ocsservers_id` (`plugin_ocsinventoryng_ocsservers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_ruleimportentities
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_ruleimportentities`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_ruleimportentities` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_runningprocesses`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_runningprocesses` (
-  `id` INT(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` INT(11) NOT NULL DEFAULT '0',
-  `cpuusage` VARCHAR(255) DEFAULT NULL,
-  `tty` VARCHAR(255) DEFAULT NULL,
-  `started` VARCHAR(15) DEFAULT NULL,
-  `virtualmemory` VARCHAR(255) DEFAULT NULL,
-  `processname` VARCHAR(255) DEFAULT NULL,
-  `processid` VARCHAR(255) DEFAULT NULL,
-  `username` VARCHAR(255) DEFAULT NULL,
-  `processmemory` VARCHAR(255) DEFAULT NULL,
-  `commandline` VARCHAR(255) DEFAULT NULL,
-  `description` VARCHAR(255) DEFAULT NULL,
-  `company` VARCHAR(255) DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_services`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_services` (
-  `id` INT(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` INT(11) NOT NULL DEFAULT '0',
-  `svcname` VARCHAR(128) NOT NULL,
-  `svcdn` VARCHAR(255) NOT NULL,
-  `svcstate` VARCHAR(32) DEFAULT NULL,
-  `svcdesc` VARCHAR(1536) DEFAULT NULL,
-  `svcstartmode` VARCHAR(32) DEFAULT NULL,
-  `svcpath` VARCHAR(512) DEFAULT NULL,
-  `svcstartname` VARCHAR(128) DEFAULT NULL,
-  `svcexitcode` INTEGER DEFAULT NULL,
-  `svcspecexitcode` INTEGER DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_ocsalerts`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_ocsalerts` (
-  `id` int(11) NOT NULL auto_increment,
-  `entities_id` int(11) NOT NULL default '0',
-  `delay_ocs` int(11) NOT NULL default '-1',
-  `use_newocs_alert` int(11) NOT NULL default '-1',
-  PRIMARY KEY  (`id`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_notificationstates`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_notificationstates` (
-  `id` int(11) NOT NULL auto_increment,
-  `states_id` int(11) NOT NULL default '0' COMMENT 'RELATION to glpi_states (id)',
-  PRIMARY KEY  (`id`)
-) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_customapps
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_customapps`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_customapps` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` int(11) NOT NULL DEFAULT '0',
-  `path` varchar(255) DEFAULT NULL,
-  `text` TEXT DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-### Dump table glpi_plugin_ocsinventoryng_bitlockerstatuses
-DROP TABLE IF EXISTS `glpi_plugin_ocsinventoryng_bitlockerstatuses`;
-CREATE TABLE `glpi_plugin_ocsinventoryng_bitlockerstatuses` (
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `computers_id` int(11) NOT NULL DEFAULT '0',
-  `item_disks_id` int(11) NOT NULL DEFAULT '0',
-  `volume_type` varchar(255) DEFAULT NULL,
-  `protection_status` varchar(255) DEFAULT NULL,
-  `init_project` varchar(255) DEFAULT NULL,
-  PRIMARY KEY (`id`),
-  KEY `computers_id` (`computers_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-
-INSERT INTO `glpi_plugin_ocsinventoryng_configs`(`id`,`thread_log_frequency`,`is_displayempty`,`import_limit`, `allow_ocs_update`, `delay_refresh`) VALUES (1, 2, 1, 0, 1, 5);
+INSERT INTO `glpi_plugin_ocsinventoryng_configs`(`id`,`thread_log_frequency`,`is_displayempty`,`import_limit`) VALUES (1, 2, 1, 0);
 
 INSERT INTO `glpi_plugin_ocsinventoryng_networkporttypes` VALUES (NULL, 'Unkown port', '*', '*', 'PluginOcsinventoryngNetworkPort', NULL, NULL,NULL, NULL);
 INSERT INTO `glpi_plugin_ocsinventoryng_networkporttypes` VALUES (NULL, 'Ethernet port', 'Ethernet', '*', 'NetworkPortEthernet', 'T', 10,NULL, NULL);
@@ -557,4 +420,4 @@ INSERT INTO `glpi_displaypreferences` (`itemtype`, `num`, `rank`, `users_id`)
                        ('PluginOcsinventoryngDetail', 3, 3, 0),
                        ('PluginOcsinventoryngDetail', 4, 4, 0),
                        ('PluginOcsinventoryngDetail', 6, 5, 0),
-                       ('PluginOcsinventoryngDetail', 80, 6, 0);
+                       ('PluginOcsinventoryngDetail', 80, 6, 0);
\ No newline at end of file
